fisx: fisx::TransmissionTable Class Reference

fisx

Public Member Functions | List of all members
fisx::TransmissionTable Class Reference

## Public Member Functions
| TransmissionTable ()
| TransmissionTable (const std::string &name, const std::string &comment="")
void | setName (const std::string &name)
void | setComment (const std::string &comment)
void | setTransmissionTable (const std::map< double, double > &table, const std::string &name="", const std::string &comment="")
void | setTransmissionTable (const std::vector< double > &energy, const std::vector< double > &transmission, const std::string &name="", const std::string &comment="")
std::map< double, double > | getTransmissionTable () const
double | getTransmission (const double &energy) const
std::vector< double > | getTransmission (const std::vector< double > &energy) const
std::string | getName () const
std::string | getComment () const

## Constructor & Destructor Documentation

## § TransmissionTable() [1/2]

fisx::TransmissionTable::TransmissionTable | ( |  | ) |

Minimalist constructor.

## § TransmissionTable() [2/2]

fisx::TransmissionTable::TransmissionTable | ( | const std::string & | name,
|  | const std::string & | comment = `""`
| ) |  |

Expected constructor.

Just a name and a description.

## Member Function Documentation

## § getTransmission() [1/2]

double fisx::TransmissionTable::getTransmission | ( | const double & | energy | ) | const

Return the transmission at a given energy by log-log interpolation into the internal table

## § getTransmission() [2/2]

std::vector< double > fisx::TransmissionTable::getTransmission | ( | const std::vector< double > & | energy | ) | const

Return the transmission at a set of energy by linear interpolation into the internal table

## § getTransmissionTable()

std::map< double, double > fisx::TransmissionTable::getTransmissionTable | ( |  | ) | const

Retrieves the internal table of energies and associated transmission

## § setTransmissionTable() [1/2]

void fisx::TransmissionTable::setTransmissionTable | ( | const std::map< double, double > & | table,
|  | const std::string & | name = `""`,
|  | const std::string & | comment = `""`
| ) |  |

Provide the table as a map of doubles.

## § setTransmissionTable() [2/2]

void fisx::TransmissionTable::setTransmissionTable | ( | const std::vector< double > & | energy,
|  | const std::vector< double > & | transmission,
|  | const std::string & | name = `""`,
|  | const std::string & | comment = `""`
| ) |  |

Alternative method to provide the table via two lists of doubles

The documentation for this class was generated from the following files:

- fisx_transmissiontable.h
- fisx_transmissiontable.cpp